@@ -3,9 +3,9 @@ package Acme::CPANModules::PortedFrom::PHP;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-31'; # DATE
+our $DATE = '2024-01-09'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-PHP'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $LIST = {
     summary => "List of modules/applications that are ported from (or inspired by) ".
@@ -16,8 +16,19 @@ If you know of others, please drop me a message.
 
 _
     entries => [
-        {module=>'Weasel', summary=>'Mink'},
-        {module=>'PHP::Functions::Password', summary=>'PHP password functions'},
+        {module=>'Weasel', summary=>'Perl port of Mink'},
+        {module=>'PHP::Functions::Password'},
+        {module=>'PHP::Functions::Mail'},
+        {module=>'PHP::Functions::File'},
+        {module=>'PHP::Strings'},
+        {module=>'PHP::DateTime'},
+        {module=>'PHP::ParseStr'},
+        {module=>'PHP::HTTPBuildQuery', summary=>'Implement PHP http_build_query() function'},
+        {module=>'Acme::Addslashes'},
+
+        # old
+        {module=>'AMF::Perl'},
+        {module=>'Flash::FLAP'},
     ],
 };
 
@@ -36,7 +47,7 @@ Acme::CPANModules::PortedFrom::PHP - List of modules/applications that are porte
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::CPANModules::PortedFrom::PHP (from Perl distribution Acme-CPANModules-PortedFrom-PHP), released on 2023-10-31.
+This document describes version 0.006 of Acme::CPANModules::PortedFrom::PHP (from Perl distribution Acme-CPANModules-PortedFrom-PHP), released on 2024-01-09.
 
 =head1 DESCRIPTION
 
@@ -48,16 +59,52 @@ If you know of others, please drop me a message.
 
 =item L<Weasel>
 
-Mink.
+Perl port of Mink.
 
 Author: L<EHUELS|https://metacpan.org/author/EHUELS>
 
 =item L<PHP::Functions::Password>
 
-PHP password functions.
-
 Author: L<CMANLEY|https://metacpan.org/author/CMANLEY>
 
+=item L<PHP::Functions::Mail>
+
+Author: L<YAPPO|https://metacpan.org/author/YAPPO>
+
+=item L<PHP::Functions::File>
+
+Author: L<TNAGA|https://metacpan.org/author/TNAGA>
+
+=item L<PHP::Strings>
+
+Author: L<KUDARASP|https://metacpan.org/author/KUDARASP>
+
+=item L<PHP::DateTime>
+
+Author: L<BLUEFEET|https://metacpan.org/author/BLUEFEET>
+
+=item L<PHP::ParseStr>
+
+Author: L<ABAYLISS|https://metacpan.org/author/ABAYLISS>
+
+=item L<PHP::HTTPBuildQuery>
+
+Implement PHP http_build_query() function.
+
+Author: L<MSCHILLI|https://metacpan.org/author/MSCHILLI>
+
+=item L<Acme::Addslashes>
+
+Author: L<JAITKEN|https://metacpan.org/author/JAITKEN>
+
+=item L<AMF::Perl>
+
+Author: L<SIMONF|https://metacpan.org/author/SIMONF>
+
+=item L<Flash::FLAP>
+
+Author: L<SIMONF|https://metacpan.org/author/SIMONF>
+
 =back
 
 =head1 FAQ
@@ -141,7 +188,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
